The mplcursors API
==================

|

.. autosummary::
   mplcursors.Cursor
   mplcursors.cursor
   mplcursors.Selection
   mplcursors.compute_pick
   mplcursors.get_ann_text
   mplcursors.make_highlight

|

.. automodule:: mplcursors
   :members:
   :special-members: __init__
   :undoc-members:
   :show-inheritance:
